@@ -1,4 +1,4 @@
-# $Id: pfam.pm,v 1.6 2002/02/13 15:32:54 jason Exp $
+# $Id: pfam.pm,v 1.6.2.1 2002/04/18 13:05:25 jason Exp $
 #
 # BioPerl module for Bio::AlignIO::pfam
 
@@ -21,7 +21,7 @@ Bio::AlignIO::pfam - pfam sequence input/output stream
 
 =head1 SYNOPSIS
 
-Do not use this module directly.  Use it via the Bio::AlignIO class.
+Do not use this module directly.  Use it via the L<Bio::AlignIO> class.
 
 =head1 DESCRIPTION
 
@@ -58,7 +58,7 @@ use vars qw(@ISA);
 use strict;
 
 use Bio::AlignIO;
-
+use Bio::SimpleAlign;
 @ISA = qw(Bio::AlignIO);
 
 =head2 next_aln
@@ -66,7 +66,7 @@ use Bio::AlignIO;
  Title   : next_aln
  Usage   : $aln = $stream->next_aln()
  Function: returns the next alignment in the stream
- Returns : SimpleAlign object
+ Returns : L<Bio::Align::AlignI> object
  Args    : NONE
 
 =cut
@@ -124,7 +124,7 @@ sub next_aln {
  Usage   : $stream->write_aln(@aln)
  Function: writes the $aln object into the stream
  Returns : 1 for success and 0 for error
- Args    : Bio::SimpleAlign object
+ Args    : L<Bio::Align::AlignI> object
 
 
 =cut
@@ -132,7 +132,10 @@ sub next_aln {
 sub write_aln {
    my ($self,@aln) = @_;
    foreach my $aln (@aln) {
-
+       if( ! $aln || ! $aln->isa('Bio::Align::AlignI')  ) { 
+	   $self->warn("Must provide a Bio::Align::AlignI object when calling write_aln");
+	   next;
+       }
       my ($namestr,$seq,$add);
       my ($maxn);
       $maxn = $aln->maxdisplayname_length();
