@@ -32,7 +32,7 @@ SELECT fref,
   WHERE fgroup.gname=?
     AND fgroup.gclass=?
     AND fgroup.gid=fdata.gid
-    GROUP BY fref,fstrand
+    GROUP BY fref,fstrand,gname
 END
 ;
 
@@ -50,7 +50,25 @@ SELECT fref,
     AND fattribute.fattribute_name='Alias'
     AND fattribute_to_feature.fattribute_id=fattribute.fattribute_id
     AND fattribute_to_feature.fid=fdata.fid
-    GROUP BY fref,fstrand
+    GROUP BY fref,fstrand,gname
+END
+;
+
+use constant GETALIASLIKE =><<END;
+SELECT fref,
+       IF(ISNULL(gclass),'Sequence',gclass),
+       min(fstart),
+       max(fstop),
+       fstrand,
+       gname
+  FROM fdata,fgroup,fattribute,fattribute_to_feature
+  WHERE fattribute_to_feature.fattribute_value LIKE ?
+    AND fgroup.gclass=?
+    AND fgroup.gid=fdata.gid
+    AND fattribute.fattribute_name='Alias'
+    AND fattribute_to_feature.fattribute_id=fattribute.fattribute_id
+    AND fattribute_to_feature.fid=fdata.fid
+    GROUP BY fref,fstrand,gname
 END
 ;
 
@@ -249,7 +267,7 @@ sub new {
   my ($dsn,$other) = rearrange([
 				[qw(FEATUREDB DB DSN)],
 			       ],@_);
-  $dsn = "dbi:mysql:$dsn" if !ref($dsn) && $dsn !~ /^(?:dbi|DBI):mysql/;
+  $dsn = "dbi:mysql:$dsn" if !ref($dsn) && $dsn !~ /^(?:dbi|DBI):/;
   my $self = $class->SUPER::new(-dsn=>$dsn,%$other);
   $self;
 }
@@ -274,8 +292,11 @@ sub get_dna {
   my ($ref,$start,$stop,$class) = @_;
   my ($offset_start,$offset_stop);
 
+  my $has_start = defined $start;
+  my $has_stop  = defined $stop;
+
   my $reversed;
-  if ($start > $stop) {
+  if ($has_start && $has_stop && $start > $stop) {
     $reversed++;
     ($start,$stop) = ($stop,$start);
   }
@@ -286,14 +307,28 @@ sub get_dna {
   $offset_start = int($start/$cs)*$cs;
   $offset_stop  = int($stop/$cs)*$cs;
 
-  my $sth = $self->dbh->do_query('select fdna,foffset from fdna where fref=? and foffset>=? and foffset<=?',
-				 $ref,$offset_start,$offset_stop);
+  my $sth;
+  # special case, get it all
+  if (!($has_start || $has_stop)) {
+    $sth = $self->dbh->do_query('select fdna,foffset from fdna where fref=? order by foffset',$ref);
+  } 
+
+  elsif (!$has_stop) {
+    $sth = $self->dbh->do_query('select fdna,foffset from fdna where fref=? and foffset>=? order by foffset',
+				$ref,$offset_start);
+  } 
+
+  else {  # both start and stop defined
+    $sth = $self->dbh->do_query('select fdna,foffset from fdna where fref=? and foffset>=? and foffset<=? order by foffset',
+				$ref,$offset_start,$offset_stop);
+  }
+
   my $dna;
   while (my($frag,$offset) = $sth->fetchrow_array) {
-    substr($frag,0,$start-$offset) = '' if $start > $offset;
+    substr($frag,0,$start-$offset) = '' if $has_start && $start > $offset;
     $dna .= $frag;
   }
-  substr($dna,$stop-$start+1)  = '' if defined($stop) && $stop-$start+1 < length $dna;
+  substr($dna,$stop-$start+1)  = '' if $has_stop && $stop-$start+1 < length $dna;
   if ($reversed) {
     $dna = reverse $dna;
     $dna =~ tr/gatcGATC/ctagCTAG/;
@@ -351,7 +386,12 @@ sub get_abscoords {
   my $result = $self->SUPER::get_abscoords(@_);
   return $result if $result;
 
-  my $sth = $self->dbh->do_query(GETALIASCOORDS,$name,$class);
+  my $sth;
+  if ($name =~ s/\*/%/g) {
+    $sth = $self->dbh->do_query(GETALIASLIKE,$name,$class);
+  } else {
+    $sth = $self->dbh->do_query(GETALIASCOORDS,$name,$class);
+  }
   my @result;
   while (my @row = $sth->fetchrow_array) { push @result,\@row }
   $sth->finish;
@@ -455,7 +495,7 @@ sub make_features_select_part {
   my $s = <<END;
 fref,fstart,fstop,fsource,fmethod,fscore,fstrand,fphase,gclass,gname,ftarget_start,ftarget_stop,fdata.fid,fdata.gid
 END
-  $s .= ",count(fdata.fid) as c" if $options->{attributes} && keys %{$options->{attributes}}>1;
+  $s .= ",count(fdata.fid)" if $options->{attributes} && keys %{$options->{attributes}}>1;
   $s;
 }
 
@@ -550,7 +590,10 @@ sub make_features_group_by_part {
   my $att = $options->{attributes} or return;
   my $key_count = keys %$att;
   return unless $key_count > 1;
-  return ("fdata.fid having c > ?",$key_count-1);
+  return ("fdata.fid,fref,fstart,fstop,fsource,
+           fmethod,fscore,fstrand,fphase,gclass,gname,ftarget_start,
+           ftarget_stop,fdata.gid 
+     HAVING count(fdata.fid) > ?",$key_count-1);
 }
 
 =head2 refseq_query
@@ -946,7 +989,7 @@ sub make_types_group_part {
   my $self = shift;
   my ($srcseq,$start,$stop,$want_count) = @_;
   return unless $srcseq or $want_count;
-  return 'ftype.ftypeid';
+  return 'ftype.ftypeid,ftype.fmethod,ftype.fsource';
 }
 
 
@@ -1085,6 +1128,7 @@ create table fattribute_to_feature (
         fattribute_id    int(10) not null,
 	fattribute_value text,
         key(fid,fattribute_id),
+	key(fattribute_value(48)),
         fulltext(fattribute_value)
 )
     },
