@@ -1,4 +1,4 @@
-# $Id: WebDBSeqI.pm,v 1.13.2.1 2002/03/13 16:37:05 jason Exp $
+# $Id: WebDBSeqI.pm,v 1.13.2.2 2002/04/27 14:38:35 jason Exp $
 #
 # BioPerl module for Bio::DB::WebDBSeqI
 #
@@ -369,7 +369,8 @@ sub get_seq_stream {
 	    open(ERR, "<$tmpfile");
 	    while(<ERR>) { $self->debug($_);}
 	} 
-	$stream = new Bio::SeqIO('-format' => $ioformat,
+	$stream = new Bio::SeqIO('-verbose' => $self->verbose,
+				 '-format' => $ioformat,
 				 '-file'   => $tmpfile);
     } elsif( $self->retrieval_type =~ /io_string/i ) {
 	my ($resp) = $self->_request($request);
@@ -382,7 +383,8 @@ sub get_seq_stream {
 	$self->postprocess_data('type'=> 'string',
 				'location' => $content);
         print STDERR "str is $$content\n" if ( $self->verbose > 0);
-	$stream = new Bio::SeqIO('-format' => $ioformat,
+	$stream = new Bio::SeqIO('-verbose' => $self->verbose,
+				 '-format' => $ioformat,
 				 '-fh'   => new IO::String($$content));
     } else { 
 	$self->throw("retrieval type " . $self->retrieval_type . 
