@@ -1,6 +1,6 @@
 package Bio::Graphics::FeatureFile;
 
-# $Id: FeatureFile.pm,v 1.1.2.9 2002/05/04 20:29:59 lstein Exp $
+# $Id: FeatureFile.pm,v 1.1.2.14 2002/07/04 14:40:00 lstein Exp $
 # This package parses and renders a simple tab-delimited format for features.
 # It is simpler than GFF, but still has a lot of expressive power.
 # See __END__ for the file format
@@ -14,8 +14,13 @@ Bio::Graphics::FeatureFile -- A set of Bio::Graphics features, stored in a file
  use Bio::Graphics::FeatureFile;
  my $data  = Bio::Graphics::FeatureFile->new(-file => 'features.txt');
 
- # render contents of the file onto a Bio::Graphics::Panel in one step
- $data->render($panel);
+
+ # create a new panel and render contents of the file onto it
+ my $panel = $data->new_panel;
+ my $tracks_rendered = $data->render($panel);
+
+ # or do it all in one step
+ my ($tracks_rendered,$panel) = $data->render;
 
  # for more control, render tracks individually
  my @feature_types = $data->types;
@@ -46,6 +51,12 @@ FeatureFile object has been initialized, you can interrogate it for
 its consistuent features and their settings, or render the entire file
 onto a Bio::Graphics::Panel.
 
+This moduel is a precursor of Jason Stajich's
+Bio::Annotation::Collection class, and fulfills a similar function of
+storing a collection of sequence features.  However, it also stores
+rendering information about the features, and does not currently
+follow the CollectionI interface.
+
 =head2 The File Format
 
 There are two types of entry in the file format: feature entries, and
@@ -103,16 +114,64 @@ belong to the same group named yk53c10.
 
 use strict;
 use Bio::Graphics::Feature;
+use Bio::Graphics::Panel;
 use Carp;
 use IO::File;
 use Text::Shellwords;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 # default colors for unconfigured features
 my @COLORS = qw(cyan blue red yellow green wheat turquoise orange);
 use constant WIDTH => 600;
 
+=head2 METHODS
+
+=over 4
+
+=item $features = Bio::Graphics::FeatureFile->new(@args)
+
+Create a new Bio::Graphics::FeatureFile using @args to initialize the
+object.  Arguments are -name=>value pairs:
+
+  Argument         Value
+  --------         -----
+
+   -file           Read data from a file path or filehandle.  Use
+                   "-" to read from standard input.
+
+   -text           Read data from a text scalar.
+
+   -map_coords     Coderef containing a subroutine to use for remapping
+                   all coordinates.
+
+   -smart_features Flag indicating that the features created by this
+                   module should be made aware of the FeatureFile
+		   object by calling their configurator() method.
+
+   -safe           Indicates that the contents of this file is trusted.
+                   Any option value that begins with the string "sub {"
+                   will be evaluated as a code reference.
+
+The -file and -text arguments are mutually exclusive, and -file will
+supersede the other if both are present.
+
+-map_coords points to a coderef with the following signature:
+
+  ($newref,[$start1,$end1],[$start2,$end2]....)
+            = coderef($ref,[$start1,$end1],[$start2,$end2]...)
+
+See the Bio::Graphics::Browser (part of the generic genome browser
+package) for an illustration of how to use this to do wonderful stuff.
+
+The -smart_features flag is used by the generic genome browser to
+provide features with a way to access the link-generation code.  See
+gbrowse for how this works.
+
+=back
+
+=cut
+
 # args array:
 # -file => parse from a file (- allowed for ARGV)
 # -text => parse from a text scalar
@@ -133,10 +192,12 @@ sub new {
 		    min      => undef,
 		    stat     => [],
 		    refs     => {},
+                    safe     => undef,
 		   },$class;
   $self->{coordinate_mapper} = $args{-map_coords} 
     if exists $args{-map_coords} && ref($args{-map_coords}) eq 'CODE';
   $self->{smart_features}    = $args{-smart_features} if exists $args{-smart_features};
+  $self->{safe}              = $args{-safe}           if exists $args{-safe};
 
   # call with
   #   -file
@@ -159,6 +220,100 @@ sub new {
   $self;
 }
 
+# render our features onto a panel using configuration data
+# return the number of tracks inserted
+=over 4
+
+=item ($rendered,$panel) = $features->render([$panel])
+
+Render features in the data set onto the indicated
+Bio::Graphics::Panel.  If no panel is specified, creates one.
+
+In a scalar context returns the number of tracks rendered.  In a list
+context, returns a two-element list containing the number of features
+rendered and the panel.  Use this form if you want the panel created
+for you.
+
+=back
+
+=cut
+
+sub render {
+  my $self = shift;
+  my $panel = shift;
+  my ($position_to_insert,$options,$max_bump,$max_label) = @_;
+
+  $panel ||= $self->new_panel;
+
+  # count up number of tracks inserted
+  my $tracks = 0;
+  my $color;
+  my %types = map {$_=>1} $self->configured_types;
+
+  my @configured_types   = grep {exists $self->features->{$_}} $self->configured_types;
+  my @unconfigured_types = sort grep {!exists $types{$_}}      $self->types;
+
+  my @base_config = $self->style('general');
+
+  my @override = ();
+  if ($options && ref $options eq 'HASH') {
+    @override = %$options;
+  } else {
+    $options ||= 0;
+    if ($options == 1) {  # compact
+      push @override,(-bump => 0,-label=>0);
+    } elsif ($options == 2) { #expanded
+      push @override,(-bump=>1);
+    } elsif ($options == 3) { #expand and label
+      push @override,(-bump=>1,-label=>1);
+    } elsif ($options == 4) { #hyperexpand
+      push @override,(-bump => 2);
+    } elsif ($options == 5) { #hyperexpand and label
+      push @override,(-bump => 2,-label=>1);
+    }
+  }
+
+  for my $type (@configured_types,@unconfigured_types) {
+    my $features = $self->features($type);
+    my @auto_bump;
+    push @auto_bump,(-bump  => @$features < $max_bump)  if defined $max_bump;
+    push @auto_bump,(-label => @$features < $max_label) if defined $max_label;
+
+    my @config = ( -glyph   => 'segments',         # really generic
+		   -bgcolor => $COLORS[$color++ % @COLORS],
+		   -label   => 1,
+		   -key     => $type,
+		   @auto_bump,
+		   @base_config,         # global
+		   $self->style($type),  # feature-specific
+		   @override,
+		 );
+    if (defined($position_to_insert)) {
+      $panel->insert_track($position_to_insert++,$features,@config);
+    } else {
+      $panel->add_track($features,@config);
+    }
+    $tracks++;
+  }
+  return wantarray ? ($tracks,$panel) : $tracks;
+}
+
+sub _stat {
+  my $self = shift;
+  my $fh   = shift;
+  $self->{stat} = [stat($fh)];
+}
+
+=over 4
+
+=item $error = $features->error([$error])
+
+Get/set the current error message.
+
+=back
+
+=cut
+
 sub error {
   my $self = shift;
   my $d = $self->{error};
@@ -166,6 +321,18 @@ sub error {
   $d;
 }
 
+=over 4
+
+=item $smart_features = $features->smart_features([$flag]
+
+Get/set the "smart_features" flag.  If this is set, then any features
+added to the featurefile object will have their configurator() method
+called using the featurefile object as the argument.
+
+=back
+
+=cut
+
 sub smart_features {
   my $self = shift;
   my $d = $self->{smart_features};
@@ -189,25 +356,23 @@ sub parse_file {
   my $fh   = shift or return;
   $self->_stat($fh);
 
-  $self->{seenit} = {};
+  $self->init_parse;
   while (<$fh>) {
     chomp;
     $self->parse_line($_);
   }
-  $self->consolidate_groups;
+  $self->finish_parse;
 }
 
 sub parse_text {
   my $self = shift;
   my $text = shift;
 
-  $self->{seenit} = {};
-  $self->{features} = {};
+  $self->init_parse;
   foreach (split /\r?\n|\r\n?/,$text) {
     $self->parse_line($_);
   }
-  $self->consolidate_groups;
-  delete $self->{seenit};
+  $self->finish_parse;
 }
 
 sub parse_line {
@@ -337,6 +502,19 @@ sub parse_line {
   }
 }
 
+
+=over 4
+
+=item $features->add_feature($feature [=>$type])
+
+Add a new Bio::FeatureI object to the set.  If $type is specified, the
+object will be added with the indicated type.  Otherwise, the
+feature's primary_tag() method will be invoked to get the type.
+
+=back
+
+=cut
+
 # add a feature of given type to our list
 # we use the primary_tag() method
 sub add_feature {
@@ -346,6 +524,24 @@ sub add_feature {
   push @{$self->{features}{$type}},$feature;
 }
 
+
+=over 4
+
+=item $features->add_type($type=>$hashref)
+
+Add a new feature type to the set.  The type is a string, such as
+"EST".  The hashref is a set of key=>value pairs indicating options to
+set on the type.  Example:
+
+  $features->add_type(EST => { glyph => 'generic', fgcolor => 'blue'})
+
+When a feature of type "EST" is rendered, it will use the generic
+glyph and have a foreground color of blue.
+
+=back
+
+=cut
+
 # Add a type to the list.  Hash values are used for key/value pairs
 # in the configuration.  Call as add_type($type,$configuration) where
 # $configuration is a hashref.
@@ -361,6 +557,21 @@ sub add_type {
   }
 }
 
+
+
+=over 4
+
+=item $features->set($type,$tag,$value)
+
+Change an individual option for a particular type.  For example, this
+will change the foreground color of EST features to my favorite color:
+
+  $features->set('EST',fgcolor=>'chartreuse')
+
+=back
+
+=cut
+
 # change configuration of a type.  Call as set($type,$tag,$value)
 # $type will be added if not already there.
 sub set {
@@ -383,10 +594,42 @@ sub destroy {
 
 sub DESTROY { shift->destroy(@_) }
 
+=over 4
+
+=item $value = $features->setting($stanza => $option)
+
+In the two-element form, the setting() method returns the value of an
+option in the configuration stanza indicated by $stanza.  For example:
+
+  $value = $features->setting(general => 'height')
+
+will return the value of the "height" option in the [general] stanza.
+
+Call with one element to retrieve all the option names in a stanza:
+
+  @options = $features->setting('general');
+
+Call with no elements to retrieve all stanza names:
+
+  @stanzas = $features->setting;
+
+=back
+
+=cut
+
+sub setting {
+  my $self = shift;
+  if ($self->safe) {
+     $self->code_setting(@_);
+  } else {
+     $self->_setting(@_);
+  }
+}
+
 # return configuration information
 # arguments are ($type) => returns tags for type
 #               ($type=>$tag) => returns values of tag on type
-sub setting {
+sub _setting {
   my $self = shift;
   my $config = $self->{config} or return;
   return keys %{$config} unless @_;
@@ -394,21 +637,70 @@ sub setting {
   return $config->{$_[0]}{$_[1]}  if @_ > 1;
 }
 
+
+=over 4
+
+=item $value = $features->code_setting($stanza=>$option);
+
+This works like setting() except that it is also able to evaluate code
+references.  These are options whose values begin with the characters
+"sub {".  In this case the value will be passed to an eval() and the
+resulting codereference returned.  Use this with care!
+
+=back
+
+=cut
+
 sub code_setting {
   my $self = shift;
   my $section = shift;
   my $option  = shift;
 
-  my $setting = $self->setting($section=>$option);
+  my $setting = $self->_setting($section=>$option);
   return unless defined $setting;
   return $setting if ref($setting) eq 'CODE';
   return $setting unless $setting =~ /^sub\s+\{/;
   my $coderef = eval $setting;
   warn $@ if $@;
-
-  return $self->{$section}{$option} = $coderef;
+  $self->set($section,$option,$coderef);
+  return $coderef;
 }
 
+=over 4
+
+=item $flag = $features->safe([$flag]);
+
+This gets or sets and "safe" flag.  If the safe flag is set, then
+calls to setting() will invoke code_setting(), allowing values that
+begin with the string "sub {" to be interpreted as anonymous
+subroutines.  This is a potential security risk when used with
+untrusted files of features, so use it with care.
+
+=back
+
+=cut
+
+sub safe {
+   my $self = shift;
+   my $d = $self->{safe};
+   $self->{safe} = shift if @_;
+   $self->evaluate_coderefs if $self->{safe} && !$d;
+   $d;
+}
+
+
+=over 4
+
+=item @args = $features->style($type)
+
+Given a feature type, returns a list of track configuration arguments
+suitable for suitable for passing to the
+Bio::Graphics::Panel->add_track() method.
+
+=back
+
+=cut
+
 # turn configuration into a set of -name=>value pairs suitable for add_track()
 sub style {
   my $self = shift;
@@ -420,6 +712,18 @@ sub style {
   return map {("-$_" => $hashref->{$_})} keys %$hashref;
 }
 
+
+=over 4
+
+=item $glyph = $features->glyph($type);
+
+Return the name of the glyph corresponding to the given type (same as
+$features->setting($type=>'glyph')).
+
+=back
+
+=cut
+
 # retrieve just the glyph part of the configuration
 sub glyph {
   my $self = shift;
@@ -429,6 +733,20 @@ sub glyph {
   return $hashref->{glyph};
 }
 
+
+=over 4
+
+=item @types = $features->configured_types()
+
+Return a list of all the feature types currently known to the feature
+file set.  Roughly equivalent to:
+
+  @types = grep {$_ ne 'general'} $features->setting;
+
+=back
+
+=cut
+
 # return list of configured types, in proper order
 sub configured_types {
   my $self = shift;
@@ -436,6 +754,38 @@ sub configured_types {
   return @{$types};
 }
 
+=over 4
+
+=item  @types = $features->types()
+
+This is similar to the previous method, but will return *all* feature
+types, including those that are not configured with a stanza.
+
+=back
+
+=cut
+
+sub types {
+  my $self = shift;
+  my $features = $self->{features} or return;
+  return keys %{$features};
+}
+
+
+=over 4
+
+=item @features = $features->features($type)
+
+Return a list of all the feature types of type "$type".  If the
+featurefile object was created by parsing a file or text scalar, then
+the features will be of type Bio::Graphics::Feature (which follow the
+Bio::FeatureI interface).  Otherwise the list will contain objects of
+whatever type you added with calls to add_feature().
+
+=back
+
+=cut
+
 # return features
 sub features {
   my $self = shift;
@@ -443,11 +793,6 @@ sub features {
   return $self->{features};
 }
 
-sub types {
-  my $self = shift;
-  my $features = $self->{features} or return;
-  return keys %{$features};
-}
 
 
 sub make_strand {
@@ -457,7 +802,44 @@ sub make_strand {
   return 0;
 }
 
+=over 4
+
+=item @refs = $features->refs
+
+Return the list of reference sequences referred to by this data file.
+
+=back
+
+=cut
+
+sub refs {
+  my $self = shift;
+  my $refs = $self->{refs} or return;
+  keys %$refs;
+}
+
+=over 4
+
+=item  $min = $features->min
+
+Return the minimum coordinate of the leftmost feature in the data set.
+
+=back
+
+=cut
+
 sub min { shift->{min} }
+
+=over 4
+
+=item $max = $features->max
+
+Return the maximum coordinate of the rightmost feature in the data set.
+
+=back
+
+=cut
+
 sub max { shift->{max} }
 
 sub init_parse {
@@ -474,6 +856,7 @@ sub init_parse {
 sub finish_parse {
   my $s = shift;
   $s->consolidate_groups;
+  $s->evaluate_coderefs if $s->safe;
   $s->{seenit} = {};
   $s->{groups} = {};
 }
@@ -488,6 +871,15 @@ sub consolidate_groups {
   }
 }
 
+sub evaluate_coderefs {
+  my $self = shift;
+  for my $s ($self->_setting) {
+    for my $o ($self->_setting($s)) {
+      $self->code_setting($s,$o);
+    }
+  }
+}
+
 sub split_group {
   my $group = shift;
 
@@ -533,54 +925,6 @@ sub split_group {
   return ($gclass,$gname,$tstart,$tstop,\@notes);
 }
 
-# render our features onto a panel using configuration data
-# return the number of tracks inserted
-sub render {
-  my $self = shift;
-  my $panel = shift;
-  my ($position_to_insert,$options) = @_;
-
-  $panel ||= $self->new_panel;
-
-  # count up number of tracks inserted
-  my $tracks = 0;
-  my $color;
-  my %types = map {$_=>1} $self->configured_types;
-
-  my @configured_types   = grep {exists $self->features->{$_}} $self->configured_types;
-  my @unconfigured_types = sort grep {!exists $types{$_}}      $self->types;
-
-  my @base_config = $self->style('general');
-
-  my @override = ();
-  if ($options && ref $options eq 'HASH') {
-    @override = %$options;
-  } else {
-    $options ||= 0;
-    push @override,(-bump => 1) if $options >= 1;
-    push @override,(-label =>1) if $options >= 2;
-  }
-
-  for my $type (@configured_types,@unconfigured_types) {
-    my @config = ( -glyph   => 'segments',         # really generic
-		   -bgcolor => $COLORS[$color++ % @COLORS],
-		   -label   => 1,
-		   -key     => $type,
-		   @base_config,         # global
-		   $self->style($type),  # feature-specificp
-		   @override,
-		 );
-    my $features = $self->features($type);
-    if (defined($position_to_insert)) {
-      $panel->insert_track($position_to_insert++,$features,@config);
-    } else {
-      $panel->add_track($features,@config);
-    }
-    $tracks++;
-  }
-  $tracks;
-}
-
 # create a panel if needed
 sub new_panel {
   my $self = shift;
@@ -609,11 +953,23 @@ sub new_panel {
   $panel;
 }
 
-sub _stat {
-  my $self = shift;
-  my $fh   = shift;
-  $self->{stat} = [stat($fh)];
-}
+=over 4
+
+=item $mtime = $features->mtime
+
+=item $atime = $features->atime
+
+=item $ctime = $features->ctime
+
+=item $size = $features->size
+
+Returns stat() information about the data file, for featurefile
+objects created using the -file option.  Size is in bytes.  mtime,
+atime, and ctime are in seconds since the epoch.
+
+=back
+
+=cut
 
 sub mtime {
   my $self = shift;
@@ -624,20 +980,40 @@ sub mtime {
 sub atime { shift->{stat}->[8];  }
 sub ctime { shift->{stat}->[10]; }
 sub size  { shift->{stat}->[7];  }
-sub refs {
-  my $self = shift;
-  my $refs = $self->{refs} or return;
-  keys %$refs;
-}
+
+=over 4
+
+=item $label = $features->feature2label($feature)
+
+Given a feature, determines the configuration stanza that bests
+describes it.  Uses the feature's type() method if it has it (DasI
+interface) or its primary_tag() method otherwise.
+
+=back
+
+=cut
 
 sub feature2label {
   my $self = shift;
   my $feature = shift;
-  my $type  = eval {$feature->type} or return;
-  my $label = $self->type2label($type) || $self->type2label($feature->primary_tag) || $type;
+  my $type  = eval {$feature->type} || $feature->primary_tag or return;
+  (my $basetype = $type) =~ s/:.+$//;
+  my $label = $self->type2label($type) || $self->type2label($basetype) || $type;
   $label;
 }
 
+=over 4
+
+=item $link = $features->make_link($feature)
+
+Given a feature, tries to generate a URL to link out from it.  This
+uses the 'link' option, if one is present.  This method is a
+convenience for the generic genome browser.
+
+=back
+
+=cut
+
 sub make_link {
   my $self     = shift;
   my $feature  = shift;
@@ -683,6 +1059,18 @@ sub invert_types {
   \%inverted;
 }
 
+=over 4
+
+=item $citation = $features->citation($feature)
+
+Given a feature, tries to generate a citation for it, using the
+"citation" option if one is present.  This method is a convenience for
+the generic genome browser.
+
+=back
+
+=cut
+
 # This routine returns the "citation" field.  It is here in order to simplify the logic
 # a bit in the generic browser
 sub citation {
@@ -691,6 +1079,17 @@ sub citation {
   return $self->setting($feature=>'citation');
 }
 
+=over 4
+
+=item $name = $features->name([$feature])
+
+Get/set the name of this feature set.  This is a convenience method
+useful for keeping track of multiple feature sets.
+
+=back
+
+=cut
+
 # give this feature file a nickname
 sub name {
   my $self = shift;
