@@ -1,4 +1,4 @@
-# $Id: RootI.pm,v 1.47.2.5 2002/06/06 21:36:59 jason Exp $
+# $Id: RootI.pm,v 1.47.2.6 2002/07/01 22:31:14 sac Exp $
 #
 # BioPerl module for Bio::Root::RootI
 #
@@ -108,8 +108,7 @@ use Carp 'confess','carp';
 BEGIN { 
     $ID        = 'Bio::Root::RootI';
     $VERSION   = 1.0;
-    $Revision  = '$Id: RootI.pm,v 1.47.2.5 2002/06/06 21:36:59 jason Exp $ ';
-    $VERSION   = 1.0;
+    $Revision  = '$Id: RootI.pm,v 1.47.2.6 2002/07/01 22:31:14 sac Exp $ ';
     $DEBUG     = 0;
     $VERBOSITY = 0;
 }
@@ -179,7 +178,7 @@ sub throw{
 
    my $std = $self->stack_trace_dump();
 
-   my $out = "-------------------- EXCEPTION --------------------\n".
+   my $out = "\n-------------------- EXCEPTION --------------------\n".
        "MSG: ".$string."\n".$std."-------------------------------------------\n";
    die $out;
 
@@ -211,7 +210,7 @@ sub warn{
     } elsif( $verbose == -1 ) {
 	return;
     } elsif( $verbose == 1 ) {
-	my $out = "-------------------- WARNING ---------------------\n".
+	my $out = "\n-------------------- WARNING ---------------------\n".
 		"MSG: ".$string."\n";
 	$out .= $self->stack_trace_dump;
 	
@@ -219,7 +218,7 @@ sub warn{
 	return;
     }    
 
-    my $out = "-------------------- WARNING ---------------------\n".
+    my $out = "\n-------------------- WARNING ---------------------\n".
        "MSG: ".$string."\n".
 	   "---------------------------------------------------\n";
     print STDERR $out;
@@ -261,6 +260,7 @@ sub deprecated{
    }
 }
 
+		     
 =head2 verbose
 
  Title   : verbose
@@ -422,8 +422,10 @@ sub _rearrange {
     # they are named or simply listed. If they are listed, we
     # can just return them. 
 
-    return @param unless (defined($param[0]) && $param[0]=~/^-/); 
-    
+    # The mod test fixes bug where a single string parameter beginning with '-' gets lost.
+    # This tends to happen in error messages such as: $obj->throw("-id not defined")
+    return @param unless (defined($param[0]) && $param[0]=~/^-/ && ($#param+1) % 2 == 0);
+
     # Tester
 #    print "\n_rearrange() named parameters:\n";
 #    my $i; for ($i=0;$i<@param;$i+=2) { printf "%20s => %s\n", $param[$i],$param[$i+1]; }; <STDIN>;
